@@ -9,13 +9,13 @@ test_that("Nice data return nice result", {
     select(patient_id, group, minute, pdr)
   comment(data) = "comment"
   fit = nls_fit(data)
-  expect_is(fit, "breathtestfit")
-  expect_is(fit, "breathtestnlsfit")
+  expect_s3_class(fit, "breathtestfit")
+  expect_s3_class(fit, "breathtestnlsfit")
   expect_identical(names(fit), c("coef", "data", "nls_fit"))
   expect_equal(comment(fit$data), "comment")
   expect_gt(sigma(fit), 0.5) # about 0.87
   cf = coef(fit)
-  expect_is(cf, "data.frame")
+  expect_s3_class(cf, "data.frame")
   expect_equal(names(cf), c("patient_id", "group", "parameter", "method", "value"))
   expect_equal(nrow(cf), 90)
 })
@@ -38,7 +38,7 @@ test_that("Single record give valid result after passing through cleanup_data",
   d = simulate_breathtest_data(n_records = 1, noise = 0.2, seed = 4711)
   data = cleanup_data(d$data)
   cf = coef(nls_fit(data))
-  expect_is(cf, "data.frame")
+  expect_s3_class(cf, "data.frame")
   expect_equal(names(cf), c("patient_id", "group", "parameter", "method", "value"))
   expect_equal(nrow(cf), 9)
   expect_lt(rel_diff(d, cf, "m"), 0.01)
@@ -51,7 +51,7 @@ test_that("Nonsense record", {
   d$data$pdr = 0
   data = cleanup_data(d$data)
   fit = nls_fit(data)
-  expect_is(fit, "breathtestfit")
-  expect_is(fit, "breathtestnullfit")
+  expect_s3_class(fit, "breathtestfit")
+  expect_s3_class(fit, "breathtestnullfit")
   expect_match(comment(fit$data), "no valid fit")
 })
